# RecordIdCommentsBody

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**text** | **str** | The comment text, may include @[userId] mentions | 
**parent_comment_id** | **str** | ID of parent comment if this is a reply | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

